#
# spec file for package liblo
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname	liblo7
Name:           liblo
Version:        0.28
Release:        10.4
Summary:        Lightweight Open Sound Control implementation
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://plugin.org.uk/liblo/
Source:         http://downloads.sourceforge.net/liblo/%{name}-%{version}.tar.gz
Source100:      baselibs.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is a lightweight, easy-to-use implementation of the OSC protocol
(see http://www.cnmat.berkeley.edu/OpenSoundControl/ for details).

%package -n %{lname}
Summary:        Lightweight Open Sound Control implementation
Group:          System/Libraries
# O/P added for 13.1
Obsoletes:      liblo < %{version}-%{release}
Provides:       liblo = %{version}-%{release}

%description -n %{lname}
This is a lightweight, easy-to-use implementation of the OSC protocol
(see http://www.cnmat.berkeley.edu/OpenSoundControl/ for details).

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%setup -q

%build
echo 'HTML_TIMESTAMP=NO' >> doc/reference.doxygen.in
%if 0%{?suse_version} > 1210
#  Autoconf version 2.69 or higher is required
autoreconf -fiv
%endif
%configure \
  --disable-static \
  --with-pic
make %{?_smp_mflags}

%install
make DESTDIR="$RPM_BUILD_ROOT" install
# remove example binaries
make -C examples distclean
rm -f examples/Makefile examples/Makefile.in
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README
%{_libdir}/liblo.so.*

%files devel
%defattr(-,root,root)
%doc doc/html
%doc examples
%{_bindir}/oscdump
%{_bindir}/oscsend
%{_libdir}/liblo.so
%{_includedir}/lo
%{_libdir}/pkgconfig/liblo.pc

%changelog
* Tue Jul 14 2015 mpluskal@suse.com
- Use url for source
- Explictitly depend on autoconf/automake
- Cleanup spec file with spec-clener
* Thu Feb 12 2015 olaf@aepfle.de
- Run autoreconf only with autoconf >= 2.69
* Mon Aug 25 2014 idonmez@suse.com
- Add baselibs.conf to spec file
* Mon Aug 25 2014 tiwai@suse.de
- Update to version 0.27
  * Support for sending and receiving nested bundles, including
    ref-counted memory handling for bundled messages.
  * Support for multicast in oscdump and oscsend tools.
  * Callbacks for bundle handling.
  * Select desired network interface for multicast.
  * Fix blocking semantics of lo_server_wait() / lo_server_recv().
  * Make inclusion of threading-related code optional.
  * Basic compilation script for Android.
  * Allow to optionally disable server dispatch queueing at runtime.
    (In this case messages are dispatched immediately even if they are
    timestamped for later.)
  * Support bidirectional use of TCP ports using lo_send_from().
  * Add SLIP protocol support for packetization when sending and
    receiving with TCP.
  * Allow to enable the TCP_NODELAY flag on TCP sockets.
  * Support for specifying server parameters via URL string, and also
    support for URL strings in the oscsend and oscdump tools.
  * As a result of the above, support for TCP and Unix sockets in the
    oscsend and oscdump tools.
- Update to version 0.28
  * Fixed build for Windows (MingW, MSVC) and Android platforms
  * Fixed an implicit cast issue in C++ bindings for lo::ServerThread
  * Documentation, small fixes
  * Added a function to get library version information (lo_version)
* Wed May 28 2014 crrodriguez@opensuse.org
- disable timestamps in doxygen, make build-compare happy.
* Fri Sep 20 2013 kkaempf@suse.com
- Update to version 0.26
  - Change license to LGPL 2.1 or later.
  - Change in .so version, rename to liblo7
  - Add return codes to all functions that may fail.
  - Fix memory leaks in lo_address_new_from_url(), dispatch_method(),
    lo_url_get_path()
  - Move lo_arg_size(), lo_get_path(), lo_arg_host/network_endian() back
    to lo_lowlevel.h.
  - Expose the lo_server_dispatch_data() function as public, making it
    possible to react to messages contained in an arbitrary block of
    memory.  (i.e., allows use with custom transport protocols)
  - Get protocol by ID number.
  - Keep TCP sessions open, and automatically track multiple open
    sessions in a data structure.
  - Allow access to bundle timestamp information.
  - Fix bug in lo_timetag_diff().
  - Change the value of LO_TT_IMMEDIATE to correspond with the OSC
    specification.
  - Enable SO_REUSEPORT when initializing a multicast server.
  - Update the "soname" describing API/ABI compatibility.
  - Update documentation and various bug fixes.
  - Compiles under MSVC, avoiding the use of gcc-isms when not using
    gcc.
* Wed Aug  7 2013 jengelh@inai.de
- Implement shlib packaging guidelines: liblo -> liblo0
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Removed a period at the end of a summary (fix for RPMLINT warning)
* Fri Sep 12 2008 crrodriguez@suse.de
- update to version 0.25 , 20+ bugfixes and improvements, see Changelog
- remove static libraries and "la" files
* Mon Mar 26 2007 tiwai@suse.de
- updated to version 0.24:
  * fix compile warnings
  * accepts unix socket format
    osc.unix://localhost/tmp/mysocket.sock
  * misc bugfixes
* Mon May 15 2006 tiwai@suse.de
- updated to version 0.23.
  * disable ipv6 as default
  * fixed pthread resource reaks
  * improvement on socket handling
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct  4 2005 tiwai@suse.de
- updated to 0.22.
* Thu Feb 24 2005 tiwai@suse.de
- backport fixes from 0.17:
  fixed resource leaks, made UDP messages resolve back
* Fri Jan 28 2005 tiwai@suse.de
- updated to version 0.16.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.15.
* Fri Aug 20 2004 tiwai@suse.de
- updated to version 0.9.
* Tue Aug 17 2004 tiwai@suse.de
- initial version: 0.8.
